@@ -18,7 +18,7 @@
 #' @export
 #' @import Formula
 #' 
-#' @return An object of class \code{cdfquantreg} will be returned. Generic functions such as \link{summary},\link{print} (e.g.,  \link{print.cdfqr}) and \link{coef} can be used to extract output (see \link{summary.cdfqr} for more details about the generic functions that can be used).
+#' @return An object of class \code{cdfqrH} will be returned. Generic functions such as \link{summary},\link{print} (e.g.,  \link{print.cdfqr}) and \link{coef} can be used to extract output (see \link{summary.cdfqr} for more details about the generic functions that can be used).
 #' Class of object is a list with the following output:
 #'  \describe{
 #'   \item{coefficients}{A named vector of coefficients.}
@@ -60,9 +60,22 @@ cdfquantregH <- function(formula, zero.fo = ~1, one.fo = ~1, fd = NULL, sd = NUL
   input_full <- match.call()
   
   input <- match.call(expand.dots = FALSE)
-  input_index <- match(c("formula", "data", "fd", "sd", "family", "start",
-                         "zero.fo", "one.fo", "type"), names(input), 
-                       0L)
+  input_index <-
+    match(
+      c(
+        "formula",
+        "data",
+        "fd",
+        "sd",
+        "family",
+        "start",
+        "zero.fo",
+        "one.fo",
+        "type"
+      ),
+      names(input),
+      0L
+    )
   input <- input[c(1L, input_index)]
   
   if (is.null(family) & (is.null(fd) | is.null(sd))) {
@@ -70,20 +83,20 @@ cdfquantregH <- function(formula, zero.fo = ~1, one.fo = ~1, fd = NULL, sd = NUL
   }
   
   if (!is.null(family)) {
-    fd <- strsplit(family,"-")[[1]][1]
-    sd <- strsplit(family,"-")[[1]][2]
+    fd <- strsplit(family, "-")[[1]][1]
+    sd <- strsplit(family, "-")[[1]][2]
   }
   
   
   # check the data if data frame is not provided, try to find the data in the
   # global environment
-  if (missing(data)) 
+  if (missing(data))
     data <- environment(formula)
   
   for (i in 1:ncol(data)) {
-    if (!is.numeric(data[, i])) 
+    if (!is.numeric(data[, i]))
       data[, i] <- factor(data[, i])
-  }  #turn character variables to factor 
+  }  #turn character variables to factor
   
   # check the formula
   formula <- Formula::as.Formula(formula)
@@ -94,27 +107,37 @@ cdfquantregH <- function(formula, zero.fo = ~1, one.fo = ~1, fd = NULL, sd = NUL
     formula <- paste(formula, "| 1", sep = "")
     formula <- Formula::as.Formula(formula)
   }
-
+  
   # Process unstandard input
   fd <- tolower(fd)
   sd <- tolower(sd)
   
   
   # Process data for cdf model part and formula ----
-  datacdf <- model.frame(formula, data)  # get the data with variables in the model only
+  datacdf <-
+    model.frame(formula, data)  # get the data with variables in the model only
   ydata <- as.matrix(model.frame(formula, datacdf, rhs = 0))
   
   if (any(ydata < 0) | any(ydata > 1)) {
-    warning(paste("The values of the dependent variable is rescaled into (0, 1) interval", "\n", "see scaleTR() for details"))
+    warning(
+      paste(
+        "The values of the dependent variable is rescaled into (0, 1) interval",
+        "\n",
+        "see scaleTR() for details"
+      )
+    )
     ydata <- scaleTR(ydata)
   }
   
   # Process submodels
-  data_lm <- as.matrix(model.matrix(formula, datacdf, rhs = 1))  # datamatrix for location model
-  data_pm <- as.matrix(model.matrix(formula, datacdf, rhs = 2))  # datamatrix for dispersion model
+  data_lm <-
+    as.matrix(model.matrix(formula, datacdf, rhs = 1))  # datamatrix for location model
+  data_pm <-
+    as.matrix(model.matrix(formula, datacdf, rhs = 2))  # datamatrix for dispersion model
   
   n_lm <- ncol(data_lm)  #number of parameters in mean component
-  n_pm <- ncol(data_pm)  #number of parameters in dispersion component
+  n_pm <-
+    ncol(data_pm)  #number of parameters in dispersion component
   
   n <- nrow(datacdf)  #number of responses
   k <- n_lm + n_pm  # total number of parameters
@@ -123,8 +146,8 @@ cdfquantregH <- function(formula, zero.fo = ~1, one.fo = ~1, fd = NULL, sd = NUL
   qy1 <- ifelse(ydata == 0, 1, 0)
   qy2 <- ifelse(ydata == 1, 1, 0)
   
-  zero.fo <- Formula::as.Formula(zero.fo) 
-  one.fo <- Formula::as.Formula(one.fo) 
+  zero.fo <- Formula::as.Formula(zero.fo)
+  one.fo <- Formula::as.Formula(one.fo)
   
   data_zero <- as.matrix(model.matrix(zero.fo, data, rhs = 1))
   n_zm <- ncol(data_zero)  #number of parameters in zero component
@@ -132,133 +155,100 @@ cdfquantregH <- function(formula, zero.fo = ~1, one.fo = ~1, fd = NULL, sd = NUL
   data_one <- as.matrix(model.matrix(one.fo, data, rhs = 1))
   n_om <- ncol(data_one)  #number of parameters in one component
   
-  if (type =="ZI") k <- n_lm + n_pm + n_zm # total number of parameters
-  if (type =="OI") k <- n_lm + n_pm + n_om # total number of parameters
-  if (type =="ZO") k <- n_lm + n_pm + n_zm + n_om # total number of parameters
-
+  if (type == "ZI")
+    k <- n_lm + n_pm + n_zm # total number of parameters
+  if (type == "OI")
+    k <- n_lm + n_pm + n_om # total number of parameters
+  if (type == "ZO")
+    k <- n_lm + n_pm + n_zm + n_om # total number of parameters
+  
   
   # Get log likelihood----
-  quantreg_loglik <- qrLogLikFun(fd, sd)
+  quantreg_loglik <- .qrLogLikFun(fd, sd)
   # Gradient
   grad <- qrGrad(fd, sd)
   
-  # zeroonepart <- function(h, y, qy, x, z, w, fd, sd)
-  # {
-  #   w<- as.matrix(w)
-  #   x<- as.matrix(x)
-  #   z<- as.matrix(w)
-  #   
-  #   hx = w%*%h[1: ncol(w)]
-  #   h1 <- h[-c(1:  ncol(w))]
-  #   hx <- x %*% h1[1:length(x[1, ])]
-  #   mu <- hx
-  #   gz <- z %*% h1[length(x[1, ]) + 1:length(z[1, ])]
-  #   sigma <- exp(gz)
-  #   
-  #   loglik <- rep(0, length(y))
-  #   for (i in 1:length(y)){
-  #     if(qy[i] == 0){
-  #       loglik[i] <-  sum(-qy[i]*log(1 + exp(-(hx[i]))) - (1-qy[i])*log(1 + exp(hx[i]))) + 
-  #         qrLogLik(y[i], mu[i], sigma[i], fd, sd)
-  #     }else{
-  #       loglik[i] <- sum(-qy[i]*log(1 + exp(-(hx[i]))) - (1-qy[i])*log(1 + exp(hx[i])))
-  #     }
-  #   }
-  #   -sum(loglik, na.rm = TRUE)
-  # }
   
-  if(type =="ZI"){
-    qy <- qy1;
+  if (type == "ZI") {
+    qy <- qy1
+    
     n_zo <- n_zm
     ycdf <-  ydata[qy1 == 0]
-    xmat = data_lm[qy1==0, ,drop=FALSE]
-    zmat = data_pm[qy1==0, ,drop=FALSE]
+    xmat = data_lm[qy1 == 0, , drop = FALSE]
+    zmat = data_pm[qy1 == 0, , drop = FALSE]
     
     data_zo <- data.frame(data_zero)
     data_zo$qy <- qy
-    zeroone.fo <- paste0(c("qy", as.character(zero.fo)), collapse = "")
-    zeroone.fo <- Formula::as.Formula(zeroone.fo) 
+    zeroone.fo <-
+      paste0(c("qy", as.character(zero.fo)), collapse = "")
+    zeroone.fo <- Formula::as.Formula(zeroone.fo)
   }
   
-  if(type =="OI"){
-    qy <- qy2;
+  if (type == "OI") {
+    qy <- qy2
+    
     n_zo <- n_om
     ycdf <-  ydata[qy2 == 0]
-    xmat = data_lm[qy2== 0, ,drop=FALSE]
-    zmat = data_pm[qy2== 0, ,drop=FALSE]
+    xmat = data_lm[qy2 == 0, , drop = FALSE]
+    zmat = data_pm[qy2 == 0, , drop = FALSE]
     
     data_zo <- data.frame(data_one)
     data_zo$qy <-  qy
-    zeroone.fo <- paste0(c("qy", as.character(one.fo)), collapse = "")
-    zeroone.fo <- Formula::as.Formula(zeroone.fo) 
+    zeroone.fo <-
+      paste0(c("qy", as.character(one.fo)), collapse = "")
+    zeroone.fo <- Formula::as.Formula(zeroone.fo)
   }
   
-  if(type =="ZO"){
-    ycdf <-  ydata[qy1==0 & qy2== 0]
-    xmat = data_lm[qy1==0 & qy2== 0, ,drop=FALSE]
-    zmat = data_pm[qy1==0 & qy2== 0, ,drop=FALSE]
+  if (type == "ZO") {
+    ycdf <-  ydata[qy1 == 0 & qy2 == 0]
+    xmat = data_lm[qy1 == 0 & qy2 == 0, , drop = FALSE]
+    zmat = data_pm[qy1 == 0 & qy2 == 0, , drop = FALSE]
     
     data_one <- data.frame(data_one)
     data_one$qy <-  qy2
     one.fo <- paste0(c("qy", as.character(one.fo)), collapse = "")
-    one.fo <- Formula::as.Formula(one.fo) 
+    one.fo <- Formula::as.Formula(one.fo)
     
     data_zero <- data.frame(data_zero)
     data_zero$qy <-  qy1
     zero.fo <- paste0(c("qy", as.character(zero.fo)), collapse = "")
-    zero.fo <- Formula::as.Formula(zero.fo) 
-  }
-
-  # starting values
-  if(is.null(start)){
-    # if the user does not supply starting values, generate some default values
-    start <- rep(0.1, k)
-    start_0 <- qrStart(ycdf, fd=fd, sd=sd)
-    start[n_zm + 1] <- start_0[1] #starting value for mu intercept
-    start[n_zm + n_lm + 1] <- start_0[2] #starting value for sigma intercept
+    zero.fo <- Formula::as.Formula(zero.fo)
   }
   
-  # Esimating First approach-
-  # if(type == "ZI" | type == "OI"){
-  #   preopt <- optim(start, fn = zeroonepart, hessian = F, x = data_lm, y = ydata, 
-  #                   z = data_pm, w = data_pm, qy = qy, fd=fd, sd=sd,
-  #                   method = "Nelder-Mead")
-  #   
-  #   contr.method <- control$method
-  #   #contr.hessian <- control$hessian
-  #   contr.hessian <- TRUE
-  #   contr.trace <- control$trace
-  #   contr.maxit <- control$maxit
-  #   
-  #   betaopt <- optim(preopt$par, fn = zeroonepart,x = data_lm, y = ydata, 
-  #                    z = data_pm, w = data_pm, qy = qy, fd=fd, sd=sd,
-  #                    hessian = contr.hessian, method = contr.method, 
-  #                    control=list(trace = contr.trace , maxit = contr.maxit))
-  #   logLiklihod <- -betaopt$value
-  # }
-
+  # starting values
+  if (is.null(start)) {
+    # if the user does not supply starting values, generate some default values
+    start <- rep(0.1, k)
+    start_0 <- qrStart(ycdf, fd = fd, sd = sd)
+    start[n_zm + 1] <- start_0[1] #starting value for mu intercept
+    start[n_zm + n_lm + 1] <-
+      start_0[2] #starting value for sigma intercept
+  }
+  
+  
   # Estimation - Two stage apporach---------
-  if(type == "ZI" | type == "OI"){
+  if (type == "ZI" | type == "OI") {
     data$qy = qy
     #fit zero/one part--
     ZOpart <- glm(zeroone.fo, data = data, family = binomial)
     
     #extract estimated values
-    zstatzo <- coef(ZOpart)/sqrt(diag(vcov(ZOpart)))
-    est_zo <-  cbind(estim <-  coef(ZOpart), 
-                   serr <- sqrt(diag(vcov(ZOpart))), 
-                   zstat <- zstatzo,
-                   prob <- 2 * (1 - pnorm(abs(zstatzo))))
-    colnames(est_zo) <- c("Estimate", "Std. Error", "z value", "Pr(>|z|)")
+    zstatzo <- coef(ZOpart) / sqrt(diag(vcov(ZOpart)))
+    est_zo <-  cbind(estim <-  coef(ZOpart),
+                     serr <- sqrt(diag(vcov(ZOpart))),
+                     zstat <- zstatzo,
+                     prob <- 2 * (1 - pnorm(abs(zstatzo))))
+    colnames(est_zo) <-
+      c("Estimate", "Std. Error", "z value", "Pr(>|z|)")
     
     #extract fitted value and residuals
     fitted_zop <- ZOpart$fitted.values
     residual_zop <- ZOpart$residuals
     deviance_zop <- ZOpart$deviance
     vcov_zop <- vcov(ZOpart)
-    if(type == "ZI"){
+    if (type == "ZI") {
       est_zm <- est_zo
-      est_om <-NULL
+      est_om <- NULL
       fitted_zp <- fitted_zop
       fitted_op <- NULL
       residual_zp <- residual_zop
@@ -269,7 +259,7 @@ cdfquantregH <- function(formula, zero.fo = ~1, one.fo = ~1, fd = NULL, sd = NUL
       vcov_op <- NULL
       mod_zp <- ZOpart
       mod_op <- NULL
-    }else{
+    } else{
       est_zm <- NULL
       est_om <- est_zo
       fitted_zp <- NULL
@@ -283,12 +273,20 @@ cdfquantregH <- function(formula, zero.fo = ~1, one.fo = ~1, fd = NULL, sd = NUL
       mod_zp <- NULL
       mod_op <- ZOpart
     }
-  
-  
+    
+    
     
     #fit cdfquantreg part--
-    preopt <- optim(start[-c(1:n_zo)], fn = quantreg_loglik, hessian = F, 
-                    x = xmat, z = zmat, y = ycdf, method = "Nelder-Mead")
+    preopt <-
+      optim(
+        start[-c(1:n_zo)],
+        fn = quantreg_loglik,
+        hessian = F,
+        x = xmat,
+        z = zmat,
+        y = ycdf,
+        method = "Nelder-Mead"
+      )
     
     contr.method <- control$method
     #contr.hessian <- control$hessian
@@ -296,33 +294,43 @@ cdfquantregH <- function(formula, zero.fo = ~1, one.fo = ~1, fd = NULL, sd = NUL
     contr.trace <- control$trace
     contr.maxit <- control$maxit
     
-    betaopt <- optim(preopt$par, fn = quantreg_loglik,x = xmat, z = zmat, y = ycdf,
-                     hessian = contr.hessian, method = contr.method, 
-                     control=list(trace = contr.trace , maxit = contr.maxit))
+    betaopt <-
+      optim(
+        preopt$par,
+        fn = quantreg_loglik,
+        x = xmat,
+        z = zmat,
+        y = ycdf,
+        hessian = contr.hessian,
+        method = contr.method,
+        control = list(trace = contr.trace , maxit = contr.maxit)
+      )
     
     logLiklihod <- -betaopt$value + as.numeric(logLik(ZOpart))
-    }
+  }
   
-  if(type == "ZO"){
+  if (type == "ZO") {
     data$qy <- qy1
     Zeropart <- glm(zero.fo, data = data, family = binomial)
     
     #extract estimated values
-    zstatz <- coef(Zeropart)/sqrt(diag(vcov(Zeropart)))
-    est_zm <-  cbind(estim <-  coef(Zeropart), 
-                     serr <- sqrt(diag(vcov(Zeropart))), 
+    zstatz <- coef(Zeropart) / sqrt(diag(vcov(Zeropart)))
+    est_zm <-  cbind(estim <-  coef(Zeropart),
+                     serr <- sqrt(diag(vcov(Zeropart))),
                      zstat <- zstatz,
                      prob <- 2 * (1 - pnorm(abs(zstatz))))
-    colnames(est_zm) <- c("Estimate", "Std. Error", "z value", "Pr(>|z|)")
+    colnames(est_zm) <-
+      c("Estimate", "Std. Error", "z value", "Pr(>|z|)")
     
     data$qy = qy2
     Onepart <- glm(one.fo, data = data, family = binomial)
-    zstato <- coef(Onepart)/sqrt(diag(vcov(Onepart)))
-    est_om <-  cbind(estim <-  coef(Onepart), 
-                     serr <- sqrt(diag(vcov(Onepart))), 
+    zstato <- coef(Onepart) / sqrt(diag(vcov(Onepart)))
+    est_om <-  cbind(estim <-  coef(Onepart),
+                     serr <- sqrt(diag(vcov(Onepart))),
                      zstat <- zstato,
                      prob <- 2 * (1 - pnorm(abs(zstato))))
-    colnames(est_om) <- c("Estimate", "Std. Error", "z value", "Pr(>|z|)")
+    colnames(est_om) <-
+      c("Estimate", "Std. Error", "z value", "Pr(>|z|)")
     
     #extract fitted value and residuals
     fitted_zp <- Zeropart$fitted.values
@@ -338,11 +346,16 @@ cdfquantregH <- function(formula, zero.fo = ~1, one.fo = ~1, fd = NULL, sd = NUL
     vcov_op <- vcov(Onepart)
     mod_op <- Onepart
     
-    preopt <- optim(start[-c(1:(n_zm+n_om))], fn = quantreg_loglik, hessian = F, 
-                    x = xmat, 
-                    y = ycdf, 
-                    z = zmat, 
-                    method = "Nelder-Mead")
+    preopt <-
+      optim(
+        start[-c(1:(n_zm + n_om))],
+        fn = quantreg_loglik,
+        hessian = F,
+        x = xmat,
+        y = ycdf,
+        z = zmat,
+        method = "Nelder-Mead"
+      )
     
     contr.method <- control$method
     #contr.hessian <- control$hessian
@@ -350,18 +363,23 @@ cdfquantregH <- function(formula, zero.fo = ~1, one.fo = ~1, fd = NULL, sd = NUL
     contr.trace <- control$trace
     contr.maxit <- control$maxit
     
-    betaopt <- optim(preopt$par, fn = quantreg_loglik,
-                     x = xmat, 
-                     y = ycdf, 
-                     z = zmat, 
-                     hessian = contr.hessian, method = contr.method, 
-                     control=list(trace = contr.trace , maxit = contr.maxit))
+    betaopt <- optim(
+      preopt$par,
+      fn = quantreg_loglik,
+      x = xmat,
+      y = ycdf,
+      z = zmat,
+      hessian = contr.hessian,
+      method = contr.method,
+      control = list(trace = contr.trace , maxit = contr.maxit)
+    )
     
-    # ***************************** 
-    logLiklihod <- -betaopt$value + logLik(Zeropart)+ logLik(Onepart)
+    # *****************************
+    logLiklihod <-
+      -betaopt$value + logLik(Zeropart) + logLik(Onepart)
   }
   
- gradients <- grad(betaopt$par,ycdf,xmat,zmat)
+  gradients <- grad(betaopt$par, ycdf, xmat, zmat)
   # Convergence message from optim
   converge <- betaopt$convergence
   
@@ -371,29 +389,32 @@ cdfquantregH <- function(formula, zero.fo = ~1, one.fo = ~1, fd = NULL, sd = NUL
   
   # estimation--------------------
   estim <- betaopt$par  #mean estiamte
-  serr <- sqrt(sqrt(diag(solve(betaopt$hessian))^2))  # se
-  zstat <- estim/serr  # z-test
+  serr <- sqrt(sqrt(diag(solve(betaopt$hessian)) ^ 2))  # se
+  zstat <- estim / serr  # z-test
   prob <- 2 * (1 - pnorm(abs(zstat)))  # p value
   
-  est <- cbind(estim <- estim, 
-               serr <- serr, 
-               zstat <- estim/serr,
+  est <- cbind(estim <- estim,
+               serr <- serr,
+               zstat <- estim / serr,
                prob <- 2 * (1 - pnorm(abs(zstat))))
-  colnames(est) <- c("Estimate", "Std. Error", "z value", "Pr(>|z|)")
+  colnames(est) <-
+    c("Estimate", "Std. Error", "z value", "Pr(>|z|)")
   
   # Separate output depending on the submodels
-  est_lm <- est[1:n_lm, ]  #location model
-  if(n_lm==1) est_lm <- matrix(est_lm, ncol=4)
+  est_lm <- est[1:n_lm,]  #location model
+  if (n_lm == 1)
+    est_lm <- matrix(est_lm, ncol = 4)
   
   rownames(est_lm) <- colnames(data_lm)
   colnames(est_lm) <- colnames(est)
   
-  est_pm <- est[(1 + n_lm):nrow(est), ]  #dispersion model
-  if(n_pm==1) est_pm <- matrix(est_pm, ncol=4)
+  est_pm <- est[(1 + n_lm):nrow(est),]  #dispersion model
+  if (n_pm == 1)
+    est_pm <- matrix(est_pm, ncol = 4)
   rownames(est_pm) <- colnames(data_pm)
   colnames(est_pm) <- colnames(est)
   
-
+  
   # Generall fit-------------------- Loglike
   
   attr(logLiklihod, "nall") <- n
@@ -406,20 +427,25 @@ cdfquantregH <- function(formula, zero.fo = ~1, one.fo = ~1, fd = NULL, sd = NUL
   BIC <- BIC(logLiklihod)
   
   # Fitted values for cdfquant part-------------
-  if(n_lm == 1) {fitted_mu <- xmat * est_lm[, 1]
-  }else{
-    fitted_mu <- rowSums(t(apply(xmat, 1, 
-                                 function(x) x * est_lm[, 1])))
+  if (n_lm == 1) {
+    fitted_mu <- xmat * est_lm[, 1]
+  } else{
+    fitted_mu <- rowSums(t(apply(xmat, 1,
+                                 function(x)
+                                   x * est_lm[, 1])))
   }
-  if  (fd =="km"){
+  if (fd == "km") {
     #log link for parameter a in Km distribution
     fitted_mu <- exp(fitted_mu)
   }
   
   #dispersion model
-  if(n_pm == 1) {fitted_phi <- zmat * est_pm[, 1]
-  }else{
-    fitted_phi <- rowSums(t(apply(zmat, 1, function(x) x * est_pm[, 1])))
+  if (n_pm == 1) {
+    fitted_phi <- zmat * est_pm[, 1]
+  } else{
+    fitted_phi <-
+      rowSums(t(apply(zmat, 1, function(x)
+        x * est_pm[, 1])))
   }
   
   fitted_sigma <- exp(fitted_phi)
@@ -436,39 +462,45 @@ cdfquantregH <- function(formula, zero.fo = ~1, one.fo = ~1, fd = NULL, sd = NUL
   df.residual <- n - k
   
   # Deviance
-  deviance <- 2 * (qrLogLik(ycdf, fitted_mu, fitted_sigma, fd, sd) - 
-                     qrLogLik(fitted,  fitted_mu, fitted_sigma, fd, sd))
+  deviance <-
+    2 * (
+      qrLogLik(ycdf, fitted_mu, fitted_sigma, fd, sd) -
+        qrLogLik(fitted,  fitted_mu, fitted_sigma, fd, sd)
+    )
+  
   
   
-
   # Parameter variance-covariance matrix
   vcov <- solve(as.matrix(betaopt$hessian))
-  rownames(vcov) <- colnames(vcov) <- c(rownames(est_lm), 
+  rownames(vcov) <- colnames(vcov) <- c(paste('(mu)_', rownames(est_lm), sep = ""),
                                         paste('(sigma)_', rownames(est_pm), sep = ""))
   
+  
   # RMSE
-  rmse <- sqrt(mean(residuals^2))
+  rmse <- sqrt(mean(residuals ^ 2))
   
   rmseLogit <- NULL
   # RMSlogit(E)
-  for (i in 1:n){
-    if(is.nan(fitted[i])|is.na(fitted[i])){
+  for (i in 1:n) {
+    if (is.nan(fitted[i]) | is.na(fitted[i])) {
       rmseLogittemp <- NA
-    }else{
-      rmseLogittemp <-sqrt(mean((logit(fitted[i]) - logit(ycdf[i]))^2))
+    } else{
+      rmseLogittemp <- sqrt(mean((logit(fitted[i]) - logit(ycdf[i])) ^ 2))
     }
     
     rmseLogit <- c(rmseLogit, rmseLogittemp)
   }
   
- 
+  
   
   #Combine zero/one and cdf part output
   # Coefficients:
-  coefficients <- list(zero = est_zm,
-                       one = est_om,
-                       location = est_lm, 
-                       dispersion = est_pm)
+  coefficients <- list(
+    zero = est_zm,
+    one = est_om,
+    location = est_lm,
+    dispersion = est_pm
+  )
   
   # Fitted values
   fittemp <- rep(NA, n)
@@ -479,14 +511,26 @@ cdfquantregH <- function(formula, zero.fo = ~1, one.fo = ~1, fd = NULL, sd = NUL
   fittemp[qy1 == 0 & qy2 == 0] <- fitted_sigma
   fitted_sigma <- fittemp
   
-  fittedlist <- switch(fd,
-                        list(full = fitted, zerop = fitted_zp, onep = fitted_op, 
-                             mu = fitted_mu, sigma = fitted_sigma),
-                        km = list(full = fitted, zerop = fitted_zp, onep = fitted_op,
-                                  a = fitted_mu, b = fitted_sigma))
+  fittedlist <- switch(
+    fd,
+    list(
+      full = fitted,
+      zerop = fitted_zp,
+      onep = fitted_op,
+      mu = fitted_mu,
+      sigma = fitted_sigma
+    ),
+    km = list(
+      full = fitted,
+      zerop = fitted_zp,
+      onep = fitted_op,
+      a = fitted_mu,
+      b = fitted_sigma
+    )
+  )
   
   #Residuals
-  redtemp <-rep(NA, n) 
+  redtemp <- rep(NA, n)
   redtemp[qy1 == 0 & qy2 == 0] <- residuals
   residuals <- redtemp
   residuals <- list(rcdf = residuals,
@@ -501,24 +545,33 @@ cdfquantregH <- function(formula, zero.fo = ~1, one.fo = ~1, fd = NULL, sd = NUL
   deviance <- deviance_zp + deviance_op + deviance
   
   # Output
-  output <- list(family = list(fd = fd, sd = sd), type = type,call = input, 
-                 formula = formula, zero.fo = zero.fo, one.fo = one.fo,
-                 N = n, k = k, y = ydata, 
-                 coefficients = coefficients, 
-                 residuals = residuals, 
-                 fitted = fittedlist, 
-                 vcov = vcov, 
-                 logLik = logLiklihod, 
-                 deviance = deviance,
-                 aic = AIC, bic = BIC,
-                 mod_zp = mod_zp,
-                 mod_op = mod_op,
-                 df.residual = df.residual)
+  output <-
+    list(
+      family = list(fd = fd, sd = sd),
+      type = type,
+      call = input,
+      formula = formula,
+      zero.fo = zero.fo,
+      one.fo = one.fo,
+      N = n,
+      k = k,
+      y = ydata,
+      coefficients = coefficients,
+      residuals = residuals,
+      fitted = fittedlist,
+      vcov = vcov,
+      logLik = logLiklihod,
+      deviance = deviance,
+      aic = AIC,
+      bic = BIC,
+      mod_zp = mod_zp,
+      mod_op = mod_op,
+      df.residual = df.residual
+    )
   
-  class(output) <- "cdfqrH"
+  class(output) <- c("cdfqrH", "cdfqr")
   
   rm(grad)
-  #print.cdfqr(output)
   return(output)
   
 } 
